@@ -1,4 +1,3 @@
-from typing import Dict, Tuple, Optional
 import logging
 
 from angr.utils.constants import DEFAULT_STATEMENT
@@ -109,7 +108,7 @@ class PCodeIRSBConverter(Converter):
         self._statement_idx = 0
 
         # Remap all uniques s.t. they are write-once with values starting from 0
-        self._unique_tracker: Dict[int, Tuple[int, int]] = {}
+        self._unique_tracker: dict[int, tuple[int, int]] = {}
         self._unique_counter = 0
 
         self._special_op_handlers = {
@@ -188,7 +187,7 @@ class PCodeIRSBConverter(Converter):
         in1 = self._get_value(self._current_op.inputs[0])
         if op is None:
             log.warning("p-code: Unsupported opcode of type %s", opcode.__name__)
-            out = DirtyExpression(self._manager.next_atom(), opcode.__name__, bits=self._current_op.output.size * 8)
+            out = DirtyExpression(self._manager.next_atom(), opcode.__name__, [], bits=self._current_op.output.size * 8)
         else:
             out = UnaryOp(self._manager.next_atom(), op, in1, ins_addr=self._manager.ins_addr)
 
@@ -207,7 +206,7 @@ class PCodeIRSBConverter(Converter):
 
         if op is None:
             log.warning("p-code: Unsupported opcode of type %s.", opcode.__name__)
-            out = DirtyExpression(self._manager.next_atom(), opcode.__name__, bits=self._current_op.output.size * 8)
+            out = DirtyExpression(self._manager.next_atom(), opcode.__name__, [], bits=self._current_op.output.size * 8)
         else:
             out = BinaryOp(self._manager.next_atom(), op, [in1, in2], signed, ins_addr=self._manager.ins_addr)
 
@@ -245,7 +244,7 @@ class PCodeIRSBConverter(Converter):
             log.warning("Could not map register '%s' from archinfo. Mapping to %x", reg_name, reg_offset)
         return reg_offset
 
-    def _remap_temp(self, offset: int, size: int, is_write: bool) -> Optional[int]:
+    def _remap_temp(self, offset: int, size: int, is_write: bool) -> int | None:
         """
         Remap any unique space addresses such that they are written only once
 
@@ -420,8 +419,9 @@ class PCodeIRSBConverter(Converter):
         """
         spc = self._current_op.inputs[0].getSpaceFromConst()
         out = self._current_op.output
-        assert spc.name in {"ram", "mem", "register"}
-        if spc.name == "register":
+        spc_name = spc.name.lower()
+        assert spc_name in {"ram", "mem", "register"}
+        if spc_name == "register":
             # load from register
             res = self._get_value(self._current_op.inputs[1])
             stmt = self._set_value(out, res)
@@ -443,8 +443,9 @@ class PCodeIRSBConverter(Converter):
         Convert a p-code store operation
         """
         spc = self._current_op.inputs[0].getSpaceFromConst()
-        assert spc.name in {"ram", "mem", "register"}
-        if spc.name == "register":
+        spc_name = spc.name.lower()
+        assert spc_name in {"ram", "mem", "register"}
+        if spc_name == "register":
             # store to register
             out = self._current_op.inputs[2]
             res = self._get_value(self._current_op.inputs[1])
